@@ -70,7 +70,7 @@ def add(request, form_class=DiscountForm, template_name="discounts/add.html"):
         if form.is_valid():
             discount = form.save(commit=False)
             discount = update_perms_and_save(request, form, discount)
-
+            form.save_m2m()
             messages.add_message(request, messages.SUCCESS, 'Successfully added %s' % discount)
             return redirect('discount.detail', id=discount.id)
     else:
@@ -95,7 +95,7 @@ def edit(request, id, form_class=DiscountForm, template_name="discounts/edit.htm
         if form.is_valid():
             discount = form.save(commit=False)
             discount = update_perms_and_save(request, form, discount)
-
+            form.save_m2m()
             messages.add_message(request, messages.SUCCESS, 'Successfully updated %s' % discount)
             return redirect('discount.detail', id=discount.id)
     else:
@@ -156,10 +156,17 @@ def discounted_price(request, form_class=DiscountCodeForm):
 
 @is_enabled('discounts')
 @csrf_exempt
-def discounted_prices(request, form_class=DiscountHandlingForm):
+def discounted_prices(request, check=False, form_class=DiscountHandlingForm):
     if request.method == 'POST':
         form = form_class(request.POST)
         if form.is_valid():
+            if check:
+                return HttpResponse(json.dumps(
+                {
+                    "error": False,
+                    "message": "A discount of $%s has been added." % (form.discount.value),
+                }), mimetype="text/plain")
+
             price_list, discount_total, discount_list, msg = form.get_discounted_prices()
             total = sum(price_list)
             new_prices = ';'.join([str(price) for price in price_list])
@@ -187,7 +194,6 @@ def discounted_prices(request, form_class=DiscountHandlingForm):
         "<form action='' method='post'>" + form.as_p() + "<input type='submit' value='check'> </form>",
         mimetype="text/html")
 
-
 @is_enabled('discounts')
 @login_required
 def export(request, template_name="discounts/export.html"):
